<?php

namespace Buckhill\LaravelSAML\Providers;

use Illuminate\Support\ServiceProvider;

class SAMLRoutesProvider extends ServiceProvider
{
    public function boot()
    {
        $this->loadRoutesFrom(__DIR__.'/../Http/routes.php');
    }

    private function loadRoutesFrom($path)
    {
      if(!$this->app->routesAreCached())
      {
        require $path;
      }
    }

    public function register()
    {
    }
}
